Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(841)

Unified Diff: chrome/browser/ui/cocoa/fullscreen_toolbar_controller.h

Issue 2467833003: [Mac] Move the fullscreen toolbar style to FullscreenToolbarController (Closed)
Patch Set: fix for rsesek Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/fullscreen_toolbar_controller.h
diff --git a/chrome/browser/ui/cocoa/fullscreen_toolbar_controller.h b/chrome/browser/ui/cocoa/fullscreen_toolbar_controller.h
index eab78f4cf4a12a9a86cf2579df96f722da56ec14..855b9592856f34f3e8b029973617a90169135f92 100644
--- a/chrome/browser/ui/cocoa/fullscreen_toolbar_controller.h
+++ b/chrome/browser/ui/cocoa/fullscreen_toolbar_controller.h
@@ -17,11 +17,18 @@ class FullscreenToolbarAnimationController;
@class FullscreenToolbarMouseTracker;
@class FullscreenToolbarVisibilityLockController;
-enum class FullscreenSlidingStyle {
- OMNIBOX_TABS_PRESENT, // Tab strip and omnibox both visible.
- OMNIBOX_TABS_HIDDEN, // Tab strip and omnibox both hidden.
- OMNIBOX_TABS_NONE, // Tab strip and omnibox both hidden and never
- // shown.
+// This enum class represents the appearance of the fullscreen toolbar, which
+// includes the tab strip and omnibox.
+enum class FullscreenToolbarStyle {
+ // The toolbar is present. Moving the cursor to the top
+ // causes the menubar to appear and the toolbar to slide down.
+ TOOLBAR_PRESENT,
+ // The toolbar is hidden. Moving cursor to top shows the
+ // toolbar and menubar.
+ TOOLBAR_HIDDEN,
+ // Toolbar is hidden. Moving cursor to top causes the menubar
+ // to appear, but not the toolbar.
+ TOOLBAR_NONE,
};
// Provides a controller to fullscreen toolbar for a single browser
@@ -44,12 +51,11 @@ enum class FullscreenSlidingStyle {
// object is only set when the browser is in fullscreen mode.
base::scoped_nsobject<FullscreenMenubarTracker> menubarTracker_;
// Maintains the toolbar's visibility locks for the
// OMNIBOX_TABS_HIDDEN style.
base::scoped_nsobject<FullscreenToolbarVisibilityLockController>
visibilityLockController_;
// Manages the toolbar animations for the OMNIBOX_TABS_HIDDEN style.
std::unique_ptr<FullscreenToolbarAnimationController> animationController_;
// Mouse tracker to track the user's interactions with the toolbar. This
@@ -66,24 +72,17 @@ enum class FullscreenSlidingStyle {
// Used to track the current state and make sure we properly restore the menu
// bar when this controller is destroyed.
base::mac::FullScreenMode systemFullscreenMode_;
-
- // Whether the omnibox is hidden in fullscreen.
- FullscreenSlidingStyle slidingStyle_;
}
-@property(nonatomic, assign) FullscreenSlidingStyle slidingStyle;
+@property(nonatomic, assign) FullscreenToolbarStyle toolbarStyle;
// Designated initializer.
-- (id)initWithBrowserController:(BrowserWindowController*)controller
- style:(FullscreenSlidingStyle)style;
+- (id)initWithBrowserController:(BrowserWindowController*)controller;
// Informs the controller that the browser has entered or exited fullscreen
-// mode. |-setupFullscreenToolbarForContentView:showDropdown:| should be called
-// after the window is setup, just before it is shown. |-exitFullscreenMode|
-// should be called before any views are moved back to the non-fullscreen
-// window. If |-setupFullscreenToolbarForContentView:showDropdown:| is called,
-// it must be balanced with a call to |-exitFullscreenMode| before the
-// controller is released.
+// mode. |-enterFullscreenMode| should be called when the window is about to
+// enter fullscreen. |-exitFullscreenMode| should be called before any views
+// are moved back to the non-fullscreen window.
- (void)enterFullscreenMode;
- (void)exitFullscreenMode;
@@ -122,6 +121,10 @@ enum class FullscreenSlidingStyle {
// Returns YES if the browser in in fullscreen.
- (BOOL)isInFullscreen;
+// Updates the toolbar style. If the style has changed, then the toolbar will
+// relayout.
+- (void)updateToolbarStyle;
+
// Updates the toolbar by updating the layout, menubar and dock.
- (void)updateToolbar;
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_layout_unittest.mm ('k') | chrome/browser/ui/cocoa/fullscreen_toolbar_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
@@ -44,12 +51,11 @@ enum class FullscreenSlidingStyle {
// object is only set when the browser is in fullscreen mode.
base::scoped_nsobject<FullscreenMenubarTracker> menubarTracker_;
- // Maintains the toolbar's visibility locks for the
- // OMNIBOX_TABS_HIDDEN style.
+ // Maintains the toolbar's visibility locks for the TOOLBAR_HIDDEN style.
base::scoped_nsobject<FullscreenToolbarVisibilityLockController>
visibilityLockController_;
@@ -44,12 +51,11 @@ enum class FullscreenSlidingStyle {
base::scoped_nsobject<FullscreenToolbarVisibilityLockController>
visibilityLockController_;
- // Manages the toolbar animations for the OMNIBOX_TABS_HIDDEN style.
+ // Manages the toolbar animations for the TOOLBAR_HIDDEN style.
std::unique_ptr<FullscreenToolbarAnimationController> animationController_;
// Mouse tracker to track the user's interactions with the toolbar. This
This is Rietveld 408576698